@@ -85,8 +85,6 @@ class Dns:
         mappings = self.port_mapper.list()
         domain = self.domain_config.load()
         external_ip = self.port_mapper.external_ip()
-        if len(mappings) == 0:
-            raise Exception("no port mappings defined (need at least one), not updating dns")
         if not domain:
             raise Exception("no token saved, need to call set_dns or get_dns_token first")
         if not external_ip:
